@@ -4,9 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -147,7 +145,7 @@ gcpApplication::gcpApplication ()
 			if (value) {
 				MailAgent = value;
 				int i = MailAgent.find (" %s");
-				if (i)
+				if (i > 0)
 					MailAgent.erase (i, MailAgent.size ());
 			}
 		}
