@@ -4,9 +4,7 @@
  * GChemPaint library
  * application.h 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -100,7 +98,7 @@ protected:
 	map <string, gcpDialog*> Dialogs;
 	map <string, GCallback> Callbacks;
 	gcpTool* m_pActiveTool;
-	static bool m_bInit, m_Have_ps2eps, m_Have_Ghemical;
+	static bool m_bInit, m_Have_Ghemical;
 	static map<string, string> m_SupportedPixbufFormats;
 	BonoboUINode* m_pNode;
 	char *FontName;
