@@ -4,9 +4,7 @@
  * GChemPaint library
  * arrow.cc 
  *
- * Copyright (C) 2002-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -113,7 +111,7 @@ void gcpArrow::SetSelected(GtkWidget* w, int state)
 {
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
 	GnomeCanvasGroup* group = pData->Items[this];
-	gchar* color;
+	gchar* color = NULL;
 	switch (state)
 	{	
 		case SelStateUnselected: color = Color; break;
@@ -143,6 +141,7 @@ bool gcpArrow::GetCoords(double* xstart, double* ystart, double* xend, double* y
 	*ystart = m_y;
 	*xend = m_x + m_width;
 	*yend = m_y + m_height;
+	return true;
 }
 
 void gcpArrow::Move(double x, double y, double)
