@@ -4,9 +4,7 @@
  * GChemPaint library
  * mendeleiev.cc 
  *
- * Copyright (C) 2001-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,7 +33,7 @@ static void on_element(GtkWidget *widget, guint Z, gcpMendeleievDlg *pBox)
 	pBox->OnElement(Z);
 }
 
-gcpMendeleievDlg::gcpMendeleievDlg(gcpApplication* App, int Z): gcpDialog(App, DATADIR"/gchempaint/ui/mendeleiev.glade", "mendeleiev")
+gcpMendeleievDlg::gcpMendeleievDlg(gcpApplication* App, int Z): gcpDialog(App, GLADEDIR"/mendeleiev.glade", "mendeleiev")
 {
 	GtkWidget* frame = glade_xml_get_widget(xml, "frame");
 	periodic = (GtkPeriodic*)gtk_periodic_new();
