@@ -4,9 +4,7 @@
  * GChemPaint library
  * molecule.cc 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -173,7 +171,7 @@ bool gcpMolecule::Merge(gcpMolecule* pMolecule, bool RemoveDuplicates)
 				ma->pAtom = pAtom;
 				endj = AtomMap.end ();
 				for (j = AtomMap.begin (); j != endj; j++) {
-					if (b1 = (gcpBond*) pAtom->GetBond ((*j).second->pAtom)) {
+					if ((b1 = (gcpBond*) pAtom->GetBond ((*j).second->pAtom))) {
 						b0 = (gcpBond*) (*i)->GetBond ((*j).first);
 						if (b0) {
 							ma->sb++;
@@ -451,7 +449,7 @@ Object* gcpMolecule::GetAtomAt(double x, double y, double z)
 	std::list<gcpBond*>::iterator n, end = m_Bonds.end();
 	Object* pObj = NULL;
 	for (n = m_Bonds.begin(); n != end; n++)
-		if (pObj = (*n)->GetAtomAt (x, y))
+		if ((pObj = (*n)->GetAtomAt (x, y)))
 			break;
 	return pObj;
 }
