@@ -4,9 +4,7 @@
  * GChemPaint library
  * view.cc
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -372,12 +370,8 @@ GtkWidget* gcpView::CreateNewWidget()
 		m_pData->StereoBondWidth = m_DefaultStereoBondWidth * DefaultZoomFactor;
 		m_pData->ObjectPadding = m_DefaultObjectPadding * DefaultZoomFactor;
 		m_pData->SignPadding = m_DefaultSignPadding * DefaultZoomFactor;
-		m_pData->Group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (
-									gnome_canvas_root(GNOME_CANVAS(m_pWidget)),
-									gnome_canvas_group_ext_get_type (),
-									NULL));
 		m_pData->Background = gnome_canvas_item_new(
-									m_pData->Group,
+									gnome_canvas_root(GNOME_CANVAS(m_pWidget)),
 									gnome_canvas_rect_get_type(),
 									"x1", 0.0,
 									"y1", 0.0,
@@ -385,6 +379,10 @@ GtkWidget* gcpView::CreateNewWidget()
 									"y2", (double) m_height,
 									"fill_color", "white",
 									NULL);
+		m_pData->Group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (
+									gnome_canvas_root(GNOME_CANVAS(m_pWidget)),
+									gnome_canvas_group_ext_get_type (),
+									NULL));
 		g_signal_connect(G_OBJECT(m_pData->Background), "event", G_CALLBACK(on_event), m_pWidget);
 		g_signal_connect(G_OBJECT(m_pWidget), "destroy", G_CALLBACK(on_destroy), this);
 		g_signal_connect(G_OBJECT(m_pWidget), "size_allocate", G_CALLBACK(on_size), this);
@@ -1062,6 +1060,7 @@ void gcpView::ExportImage (const char* filename, const char* type)
 	} else {
 		gnome_canvas_update_now (GNOME_CANVAS (m_pWidget));
 		GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
+		gdk_pixbuf_fill (pixbuf, 0xffffffff);
 		GnomeCanvasBuf buf;
 		buf.buf = gdk_pixbuf_get_pixels (pixbuf);
 		buf.rect.x0 = (int) floor (rect.x0);
