@@ -74,7 +74,7 @@ void gcpArrowsPlugin::Populate (gcpApplication* App)
 	}
 	gconf_client_remove_dir (conf_client, "/apps/gchempaint/plugins/arrows", NULL);
 	g_object_unref (conf_client);
-	App->AddUI (PKGDATADIR"/ui/arrows.xml");
+	App->AddUI (GLADEDIR"/arrows.xml");
 	new gcpArrowTool (App);
 	new gcpArrowTool (App, FullHeads? gcpFullReversibleArrow: gcpReversibleArrow);
 	new gcpArrowTool (App, gcpDoubleHeadedArrow);
