@@ -39,7 +39,7 @@ gcpBondsPlugin::~gcpBondsPlugin()
 
 void gcpBondsPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (PKGDATADIR"/ui/bonds.xml");
+	App->AddUI (GLADEDIR"/bonds.xml");
 	new gcpBondTool(App);
 	new gcpUpBondTool (App);
 	new gcpDownBondTool (App);
