@@ -39,7 +39,7 @@ gcpCyclesPlugin::~gcpCyclesPlugin()
 
 void gcpCyclesPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (PKGDATADIR"/ui/cycles.xml");
+	App->AddUI (GLADEDIR"/cycles.xml");
 	new gcpCycleTool (App, 3);
 	new gcpCycleTool (App, 4);
 	new gcpCycleTool (App, 5);
