@@ -48,7 +48,7 @@ gcpSelectionPlugin::~gcpSelectionPlugin()
 
 void gcpSelectionPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (PKGDATADIR"/ui/selection.xml");
+	App->AddUI (GLADEDIR"/selection.xml");
 	new gcpSelectionTool (App);
 	new gcpEraserTool (App);
 	App->ActivateTool ("Select", true);
