@@ -4,9 +4,7 @@
  * GChemPaint templates plugin
  * templatetree.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -61,6 +59,7 @@ static void on_templates(GtkWidget *w, gcpApplication* App)
 
 map<string, gcpTemplate*> Templates, TempbyName;
 set<string> categories;
+set<xmlDocPtr> docs;
 xmlDocPtr user_templates = NULL;
 
 gcpTemplate::gcpTemplate ()
@@ -86,7 +85,6 @@ gcpTemplateTree::gcpTemplateTree(gcpApplication* App): gcpTool (App, "TemplateTr
 {
 	model = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING);
 	GtkTreeIter iter, child_iter;
-	TreeItem item;
 	map<string, gcpTemplate*>::iterator i, end = Templates.end();
 	string category;
 	for (i = Templates.begin(); i!= end; i++) {
@@ -143,8 +141,7 @@ void gcpTemplateTree::AddTemplate (string& key)
 	map<string, gcpTemplate*>::iterator i = Templates.find (key), end = Templates.end ();
 	GtkTreeIter iter, parent;
 	GtkTreePath *path;
-	char *s;
-	gcpTemplate *t, *t1, *new_temp = (*i).second;
+	gcpTemplate *t, *new_temp = (*i).second;
 	if (i == Templates.begin()) {
 		i++;
 		if (i == end || ((*i).second->category != new_temp->category)) {
