@@ -42,7 +42,7 @@ gcpTextPlugin::~gcpTextPlugin()
 
 void gcpTextPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (PKGDATADIR"/ui/text.xml");
+	App->AddUI (GLADEDIR"/text.xml");
 	new gcpTextTool (App);
 	new gcpFragmentTool (App);
 }
