@@ -4,9 +4,7 @@
  * GChemPaint text plugin
  * texttool.cc 
  *
- * Copyright (C) 2002-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -70,10 +68,9 @@ gcpTextTool::~gcpTextTool()
 
 bool gcpTextTool::OnClicked()
 {
-	void *func;
-	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != TextType) || (m_Active != m_pData->Items[m_pObject]->item_list->data)))
-	{
-		Unselect();
+	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType () != TextType) ||
+			(m_Active != g_object_get_data (G_OBJECT (m_pData->Items[m_pObject]), "text")))) {
+		Unselect ();
 	}
 	if (!m_pObject)
 	{
@@ -135,24 +132,24 @@ bool gcpTextTool::OnEvent(GdkEvent* event)
 						CutSelection(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD));
 						return true;
 					case GDK_i:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Italic"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Italic")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("italic"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("italic")));
 						return true;
 					case GDK_u:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Underline"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Underline")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("underline"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("underline")));
 						return true;
 					case GDK_b:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Bold"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Bold")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("bold"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("bold")));
 						return true;
 					case GDK_plus:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Superscript"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Superscript")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("superscript"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("superscript")));
 						return true;
 					case GDK_equal:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Subscript"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Subscript")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("subscript"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("subscript")));
 						return true;
 					default:
 						return true;
@@ -212,14 +209,7 @@ bool gcpTextTool::Deactivate()
 
 bool gcpTextTool::NotifyViewChange()
 {
-	bool result = true;
-	if (m_Active)
-	{
-		result = Unselect();
-		sleep(1);
-		while(gtk_events_pending()) gtk_main_iteration();
-	}
-	return result;
+	return (m_Active)? Unselect(): true;
 }
 
 bool gcpTextTool::Unselect()
@@ -289,7 +279,6 @@ bool gcpTextTool::Unselect()
 	if (m_CurNode) xmlFree(m_CurNode);
 	if (m_InitNode) xmlFree(m_InitNode);
 	m_CurNode = m_InitNode = NULL;
-	while(gtk_events_pending()) gtk_main_iteration();
 	if (!*text)
 	{
 		Object* pMol = pObj->GetMolecule();	//if pObj is a fragment
@@ -333,7 +322,7 @@ bool gcpTextTool::OnToggled(GtkWidget *btn)
 
 bool gcpTextTool::OnFont()
 {
-	GtkTextBuffer* buf ;
+	GtkTextBuffer* buf = NULL;
 	GtkTextIter start, end;
 	GtkWidget *dialog = gtk_font_selection_dialog_new("");
 	GtkToggleToolButton* BoldBtn = (GtkToggleToolButton*)m_pApp->GetToolItem("bold"),
