@@ -94,9 +94,9 @@ static void on_save(gpointer p, Bonobo_Stream stream, const Bonobo_Persist_Conte
 	xmlDocPtr xml = ps->pDoc->BuildXMLTree();
 	if (xml)
 	{
-		char* tmp;
+		unsigned char* tmp;
 		int size;
-		xmlDocDumpMemory(xml, (xmlChar**)(&tmp), &size);
+		xmlDocDumpMemory (xml, (xmlChar**) (&tmp), &size);
 		if (tmp)
 		{
 			bonobo_stream_client_write (stream, tmp, size, ev);
@@ -517,7 +517,7 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 
 int main (int argc, char *argv[])
 {
-	bindtextdomain(PACKAGE, DATADIR"/locale");
+	bindtextdomain(PACKAGE, LOCALEDIR);
 #ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
