@@ -4,9 +4,7 @@
  * GChemPaint
  * main.cc 
  *
- * Copyright (C) 2001-2003
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -45,7 +43,7 @@ gboolean cb_print_version (const gchar *option_name, const gchar *value, gpointe
 
 static GOptionEntry entries[] = 
 {
-  { "version", 'v', 0, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, "prints GChemPaint version", NULL },
+  { "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, "prints GChemPaint version", NULL },
    { NULL }
 };
 
@@ -53,7 +51,7 @@ int main(int argc, char *argv[])
 {
 	GOptionContext *context;
 	GError *error = NULL;
-	bindtextdomain(GETTEXT_PACKAGE, DATADIR"/locale");
+	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
 #ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
