@@ -342,8 +342,6 @@ static const char *ui_description =
 "    <toolitem action='Open'/>"
 "    <toolitem action='Save'/>"
 "    <toolitem action='Print'/>"
-"    <toolitem action='Close'/>"
-"    <toolitem action='Quit'/>"
 "  </toolbar>"
 "</ui>";
 
@@ -761,7 +759,7 @@ void gcpStandaloneApp::AddToolbar (BonoboUINode* Node, map<unsigned, GtkWidget*>
 						char* filename = NULL;
 						if (bonobo_ui_node_has_attr (Child, "pixname")) {
 							name = bonobo_ui_node_get_attr (Child, "pixname");
-							filename = g_strconcat (PKGDATADIR"/ui/", name, NULL);
+							filename = g_strconcat (GLADEDIR"/", name, NULL);
 							bonobo_ui_node_free_string (name);
 						}
 						if (filename) {
@@ -893,6 +891,8 @@ void gcpStandaloneApp::SetActive (gcpDocument* pDoc, GtkWidget* w)
 
 void gcpStandaloneApp::OnFileClose ()
 {
+	if (!m_pActiveDoc)
+		return;
 	gcpView* pView = m_pActiveDoc->GetView ();
 	pView->PrepareUnselect (); 
 	m_pActiveDoc = NULL;
@@ -904,6 +904,8 @@ void gcpStandaloneApp::OnFileClose ()
 bool gcpStandaloneApp::OnKeyPressed(GtkWidget* widget, GdkEventKey* ev)
 {
 	gint i = gtk_notebook_get_current_page(m_Book);
+	if (i < 0)
+		return true;
 	GtkWidget* w = gtk_bin_get_child(GTK_BIN(gtk_bin_get_child(GTK_BIN(gtk_notebook_get_nth_page(m_Book, i)))));
 	gcpView* v = (gcpView*) g_object_get_data(G_OBJECT(w), "view");
 	if (v && v->GetDoc()->GetEditable()) return v->OnKeyPress(w, ev);
@@ -913,6 +915,8 @@ bool gcpStandaloneApp::OnKeyPressed(GtkWidget* widget, GdkEventKey* ev)
 bool gcpStandaloneApp::OnKeyReleased(GtkWidget* widget, GdkEventKey* ev)
 {
 	gint i = gtk_notebook_get_current_page(m_Book);
+	if (i < 0)
+		return true;
 	GtkWidget* w = gtk_bin_get_child(GTK_BIN(gtk_bin_get_child(GTK_BIN(gtk_notebook_get_nth_page(m_Book, i)))));
 	gcpView* v = (gcpView*) g_object_get_data(G_OBJECT(w), "view");
 	if (v && v->GetDoc()->GetEditable()) return v->OnKeyRelease(w, ev);
